from setuptools import setup, find_packages

# Read the contents of your README file
with open('README.md', encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='env_colab_pass',
    version='0.3',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=find_packages(exclude=["tests", "tests.*"]),
    install_requires=[],
    extras_require= {
        'google-colab': ['google-colab']
    }, 
    # Other metadata
    author='Bakulkumar Kakadiya',
    author_email='bakul.kumar@gmail.com',
    description='Python library that check for key value in env and colab userdata. if not found then asks for it using getpass',
    license='Apache License Version 2.0',
    url='https://github.com/bkakadiya/env-colab-pass',
)



import os
import getpass

## Try to import Google Colab userdata
try:
    from google.colab import userdata
    from google.colab.userdata import NotebookAccessError
except ImportError:
    colab_exists = False
else:
    colab_exists = True


def get_secret_value(key):
    """
    Check in to env
    if not found check in to google colab userdata, if available
    else asks for that key, will be presented as ****
    """
    # Check in os.environ
    if key in os.environ:
        return os.environ[key]
    
    if colab_exists:
        colab_val = None

        # Check in Google Colab's user data
        try:        
            colab_val = userdata.get(key)
            return colab_val
        except NotebookAccessError as nae:
            raise nae
        except Exception:
            pass
        
    # Ask the user for the value if not found
    return getpass.getpass(f"Enter the value for {key}: ")